<?php
if (!defined('ABSPATH')) exit;
include_once(ABSPATH.'wp-admin/includes/plugin.php');


if( class_exists('Stonehenge_EM_Mollie') ) {
	global $EM_Mollie;
	$EM_Mollie = new Stonehenge_EM_Mollie_Functions();
}


Class Stonehenge_EM_Mollie_Functions {

	#===============================================
	public function __construct() {
		add_action('admin_notices', array($this, 'create_admin_notices'));
		add_filter('em_mollie_wildcards', array($this, 'wildcards'), 10, 1);
		add_shortcode('mollie-methods', array($this, 'shortcode'));
	}

	#===============================================
	function get_plugin_data() {
		$plugin = Stonehenge_EM_Mollie::get_plugin_data();
		return $plugin;
	}

	#===============================================
	function start_mollie() {

		// Initiate connection with Mollie. Replaces initialize.php. See Mollie åDev docs.
		ini_set( 'display_errors', 1 );
		ini_set( 'display_startup_errors', 1 );
		error_reporting( E_ALL );
		require_once( plugin_dir_path(__DIR__). 'vendor/autoload.php' );

		// Set the right API key => Live or Test Mode.
		$api_key = get_option('em_mollie_api_key');
		if( isset($api_key) && !empty($api_key) ) {
			$mollie = new \Mollie\Api\MollieApiClient();
			$mollie->setApiKey( $api_key );
			return $mollie;
		}
		return;
	}


	#===============================================
	function get_localized_time( $input ) {
		$UTC 	= new DateTimeZone("UTC");
		$newTZ 	= new DateTimeZone( get_option('timezone_string') );
		$date 	= new DateTime( date("Y-m-d H:i:s", strtotime($input)), $UTC );
		$date->setTimezone( $newTZ );
		$result = $date->format('Y-m-d H:i:s');
		return $result;
	}


	#===============================================
	public static function translate( $string ) {
		global $EM_Mollie;
		$plugin 	= $EM_Mollie->get_plugin_data();
		$text 		= $plugin['text'];
		$translate 	= array(
			// Statusses
			'open' 			=> __('open', $text),
			'pending' 		=> __('pending', $text),
			'paid' 			=> __('paid', $text),
			'canceled' 		=> __('canceled', $text),
			'expired' 		=> __('expired', $text),
			'failed' 		=> __('failed', $text),
			'refunded' 		=> __('refunded', $text),
			'chargeback' 	=> __('chargeback', $text),

			// Extras
			'refund' 		=> __('refund', $text),
			'charged back' 	=> __('charged back', $text),

			// Methods
			'bancontact' 	=> __('Bancontact', $text),
			'banktransfer' 	=> __('Bank Transfer', $text),
			'belfius' 		=> __('Belfius Pay Button', $text),
			'bitcoin'		=> __('Bitcoin', $text),
			'creditcard' 	=> __('Credit Card', $text),
			'directdebit' 	=> __('Direct Debit', $text),
			'eps' 			=> __('EPS', $text),
			'giftcard' 		=> __('Gift Card', $text),
			'giropay' 		=> __('Giropay', $text),
			'ideal' 		=> __('iDEAL', $text),
			'inghomepay' 	=> __('ING Home\'Pay', $text),
			'kbc' 			=> __('KBC/CBC Payment Button', $text),
			'paypal' 		=> __('PayPal', $text),
			'paysafecard' 	=> __('paysafecard', $text),
			'sofort' 		=> __('SOFORT Banking', $text),

			// Descriptions
			'Bancontact' 				=> __('Bancontact', $text),
			'Bank transfer' 			=> __('Bank Transfer', $text),
			'Belfius Pay Button'		=> __('Belfius Pay Button', $text),
			'Bitcoin'					=> __('Bitcoin', $text),
			'Credit card' 				=> __('Credit Card', $text),
			'Direct Debit' 				=> __('Direct Debit', $text),
			'eps' 						=> __('EPS', $text),
			'Gift card' 				=> __('Gift Card', $text),
			'Giropay' 					=> __('Giropay', $text),
			'iDEAL' 					=> __('iDEAL', $text),
			'ING Home\'Pay' 			=> __('ING Home\'Pay', $text),
			'KBC/CBC Payment Button' 	=> __('KBC/CBC Payment Button', $text),
			'PayPal' 					=> __('PayPal', $text),
			'paysafecard' 				=> __('paysafecard', $text),
			'SOFORT Banking' 			=> __('SOFORT Banking', $text),
		);

		if( !array_key_exists($string, $translate) ) {
			return $string;
		}

		return $translate[$string];
	}


	#===============================================
	function wildcards( $string ) {
		global $wp_rewrite, $EM_Notices, $EM_Booking, $EM_Event;

		foreach( $EM_Booking->get_tickets_bookings()->tickets_bookings as $EM_Ticket_Booking ) {
			$ticket_name = wp_kses_data( $EM_Ticket_Booking->get_ticket()->name );
		}
		$blog_name = get_bloginfo('name');

		if( get_option('dbem_multiple_bookings') ) 	{ $event_name = $event_date = $blog_name; }
		else {
			$event_date = date( get_option('dbem_date_format'), strtotime($EM_Event->start_date) ); // Return formatted date.
			$event_name = $EM_Booking->get_event()->event_name;
		}

		$wildcards = array(
			'%blog_name%' 		=> $blog_name,
			'%booking_id%'		=> '#' . $EM_Booking->booking_id,
			'%event_date%' 		=> $event_date,
			'%event_name%' 		=> $event_name,
			'%spaces%'			=> $EM_Booking->get_spaces(),
			'%ticket_name%'		=> $ticket_name,
		);

		foreach( $wildcards as $wildcard => $value ) {
			$string = str_replace( $wildcard, $value, $string );
		}
		return $string;
	}


	#===============================================
	# 	Create Admin Notices.
	#===============================================
	function create_admin_notices() {
		$settingsUrl 	= admin_url() .'edit.php?post_type=event&page=events-manager-gateways&action=edit&gateway=mollie';
		$message 		= '';

		if ( get_option('dbem_multiple_bookings') ) {
			$description = get_option('em_mollie_description');
			if( strpos( $description, '%event' )) {
				echo sprintf('<div class="notice notice-error"><p>%s<br>%s</p></div>',
					'<strong>%event_name%</strong> and <strong>%event_date%</strong> are not allowed in Multiple Bookings Mode!',
					'Please change the wildcards in your <a hef="'.$settingsUrl.'">Mollie Payment Description</a>, else <strong>%blog_name%</strong> will be used instead.'
				);
			}
		}
	}

	#===============================================
	# 	Create shortcode [mollie-methods]
	#===============================================
	function shortcode() {
		global $EM_Mollie;
		if( !is_object( $EM_Mollie->start_mollie() ) ) {
			return;
		}

		$mollie 	= $EM_Mollie->start_mollie();
		$methods 	= $mollie->methods->all();
		$shortcode 	= '';
		$shortcode .= '<div class="show-mollie-methods" id="show-mollie-methods">';
			foreach( $methods as $method ) {
				$shortcode .= sprintf( '<img src="%s" srcset="%s" alt="%s" title="%s" width="50px" height="38px"> ',
					htmlspecialchars($method->image->size1x),
					htmlspecialchars($method->image->size2x),
					$EM_Mollie->translate( htmlspecialchars($method->id) ),
					$EM_Mollie->translate( htmlspecialchars($method->id) )
				);
			}
		$shortcode .= '</div>';
		return $shortcode;
	}


} // End class.